rebase

Function rebase 

pub async fn rebase(branch_name: &str) -> Result<(), Error>
Rebase a branch and all its descendants onto trunk.

Errors

Returns an error if the branch is not found, or if git operations fail.